@@ -4,10 +4,6 @@ import numpy as np
 from typing import Callable
 from functools import wraps
 from toolz import curry
-from napari_tools_menu import register_function
-from napari_time_slicer import time_slicer
-from napari_skimage_regionprops._all_frames import analyze_all_frames
-from napari_skimage_regionprops import relabel as _relabel
 
 
 @curry
@@ -217,6 +213,8 @@ def _imshow(image, title: str = None, labels: bool = False, min_display_intensit
 
         if min_display_intensity is None:
             min_display_intensity = 0
+        if max_display_intensity is None:
+            max_display_intensity = 65556
 
     if plot is None:
         import matplotlib.pyplot as plt
